@@ -1,3 +1,4 @@
+import binascii
 import os
 import uproot
 import numpy as np
@@ -115,6 +116,11 @@ class OnlineReader:
         self._events = None
         self._timeslices = None
         self._summaryslices = None
+        self._uuid = binascii.hexlify(self._fobj._context.uuid).decode("ascii")
+
+    @property
+    def uuid(self):
+        return self._uuid
 
     def close(self):
         self._fobj.close()
