@@ -128,8 +128,8 @@ def fitinf(fitparam, tracks):
 
     Parameters
     ----------
-    fitparam : str
-        the fit parameter name according to fitparameters defined in
+    fitparam : int
+        the fit parameter key according to fitparameters defined in
         KM3NeT-Dataformat.
     tracks : km3io.offline.OfflineBranch
         the tracks class. both full tracks branch or a slice of the
@@ -141,7 +141,7 @@ def fitinf(fitparam, tracks):
         awkward array of the values of the fit parameter requested.
     """
     fit = tracks.fitinf
-    index = kfit[fitparam]
+    index = fitparam
     try:
         params = fit[count_nested(fit, axis=2) > index]
         return ak1.Array([i[:, index] for i in params])
@@ -217,7 +217,7 @@ def best_track(tracks, startend=None, minmax=None, stages=None):
         The range (minimum and maximum) value of rec_stages to take into account.
     stages : list or set, optional
         - list: the order of the rec_stages is respected.
-        - set: the order is irrelevant.
+        - set: a subset of required stages; the order is irrelevant.
 
     Returns
     -------
@@ -234,10 +234,12 @@ def best_track(tracks, startend=None, minmax=None, stages=None):
     inputs = (stages, startend, minmax)
 
     if all(v is None for v in inputs):
-        raise ValueError("either stages, startend or minmax must be specified.")
+        raise ValueError(
+            "either stages, startend or minmax must be specified.")
 
     if stages is not None and (startend is not None or minmax is not None):
-        raise ValueError("Please specify either a range or a set of rec stages.")
+        raise ValueError(
+            "Please specify either a range or a set of rec stages.")
 
     if stages is not None and startend is None and minmax is None:
         selected_tracks = tracks[mask(tracks, stages=stages)]
@@ -309,10 +311,12 @@ def mask(tracks, stages=None, startend=None, minmax=None):
     inputs = (stages, startend, minmax)
 
     if all(v is None for v in inputs):
-        raise ValueError("either stages, startend or minmax must be specified.")
+        raise ValueError(
+            "either stages, startend or minmax must be specified.")
 
     if stages is not None and (startend is not None or minmax is not None):
-        raise ValueError("Please specify either a range or a set of rec stages.")
+        raise ValueError(
+            "Please specify either a range or a set of rec stages.")
 
     if stages is not None and startend is None and minmax is None:
         if isinstance(stages, list):
@@ -320,8 +324,7 @@ def mask(tracks, stages=None, startend=None, minmax=None):
             return _mask_explicit_rec_stages(tracks, stages)
         if isinstance(stages, set):
             # order of stages is no longer conserved
-            return _mask_rec_stages_in_range_min_max(tracks,
-                                                     valid_stages=stages)
+            return _mask_rec_stages_in_set(tracks, stages)
 
     if startend is not None and minmax is None and stages is None:
         return _mask_rec_stages_between_start_end(tracks, *startend)
@@ -484,8 +487,8 @@ def best_jmuon(tracks):
         the longest + highest likelihood track reconstructed with JMUON.
     """
     mask = _mask_rec_stages_in_range_min_max(tracks,
-                                             min_stages=krec.JMUONBEGIN,
-                                             max_stages=krec.JMUONEND)
+                                             min_stage=krec.JMUONBEGIN,
+                                             max_stage=krec.JMUONEND)
 
     return _max_lik_track(_longest_tracks(tracks[mask]))
 
@@ -504,8 +507,8 @@ def best_jshower(tracks):
         the longest + highest likelihood track reconstructed with JSHOWER.
     """
     mask = _mask_rec_stages_in_range_min_max(tracks,
-                                             min_stages=krec.JSHOWERBEGIN,
-                                             max_stages=krec.JSHOWEREND)
+                                             min_stage=krec.JSHOWERBEGIN,
+                                             max_stage=krec.JSHOWEREND)
 
     return _max_lik_track(_longest_tracks(tracks[mask]))
 
@@ -524,8 +527,8 @@ def best_aashower(tracks):
         the longest + highest likelihood track reconstructed with AASHOWER.
     """
     mask = _mask_rec_stages_in_range_min_max(tracks,
-                                             min_stages=krec.AASHOWERBEGIN,
-                                             max_stages=krec.AASHOWEREND)
+                                             min_stage=krec.AASHOWERBEGIN,
+                                             max_stage=krec.AASHOWEREND)
 
     return _max_lik_track(_longest_tracks(tracks[mask]))
 
@@ -544,28 +547,26 @@ def best_dusjshower(tracks):
         the longest + highest likelihood track reconstructed with DUSJSHOWER.
     """
     mask = _mask_rec_stages_in_range_min_max(tracks,
-                                             min_stages=krec.DUSJSHOWERBEGIN,
-                                             max_stages=krec.DUSJSHOWEREND)
+                                             min_stage=krec.DUSJSHOWERBEGIN,
+                                             max_stage=krec.DUSJSHOWEREND)
 
     return _max_lik_track(_longest_tracks(tracks[mask]))
 
 
 def _mask_rec_stages_in_range_min_max(tracks,
-                                      min_stages=None,
-                                      max_stages=None,
-                                      valid_stages=None):
+                                      min_stage=None,
+                                      max_stage=None):
     """Mask tracks where rec_stages are withing the range(min, max).
 
     Parameters
     ----------
     tracks : km3io.offline.OfflineBranch
         tracks, or one track, or slice of tracks, or slices of tracks.
-    min_stages : int
-        minimum range of rec_stages.
-    max_stages : int
-        maximum range of rec_stages.
-    valid_stages : set, optional
-        set of valid stages.
+    min_stage : int
+        minimum value of rec_stages.
+    max_stage : int
+        maximum value of rec_stages.
+
 
     Returns
     -------
@@ -573,21 +574,23 @@ def _mask_rec_stages_in_range_min_max(tracks,
         an awkward1 Array mask where True corresponds to the positions
         where stages were found. False otherwise.
     """
-    if (min_stages is not None) and (max_stages
-                                     is not None) and (valid_stages is None):
-        valid_stages = set(range(min_stages, max_stages))
+    if (min_stage is not None) and (max_stage is not None):
+
+        builder = ak1.ArrayBuilder()
+        if tracks.is_single:
+            _find_in_range_single(tracks.rec_stages, min_stage, max_stage,
+                                  builder)
+            return (builder.snapshot() == 1)[0]
+        else:
+            _find_in_range(tracks.rec_stages, min_stage, max_stage, builder)
+            return builder.snapshot() == 1
 
-    builder = ak1.ArrayBuilder()
-    if tracks.is_single:
-        _find_in_range_single(tracks.rec_stages, valid_stages, builder)
-        return (builder.snapshot() == 1)[0]
     else:
-        _find_in_range(tracks.rec_stages, valid_stages, builder)
-        return builder.snapshot() == 1
+        raise ValueError("please provide min_stage and max_stage.")
 
 
 @nb.jit(nopython=True)
-def _find_in_range(rec_stages, valid_stages, builder):
+def _find_in_range(rec_stages, min_stage, max_stage, builder):
     """Construct an awkward1 array with the same structure as tracks.rec_stages.
 
     When stages are within the range(min, max), the Array is filled with
@@ -597,8 +600,10 @@ def _find_in_range(rec_stages, valid_stages, builder):
     ----------
     rec_stages : awkward1.Array
         tracks.rec_stages of MULTILPLE events.
-    valid_stages : set
-        set of valid stages.
+    min_stage: int
+        minimum value of rec_stages.
+    max_stage: int
+        minimum value of rec_stages.
     builder : awkward1.highlevel.ArrayBuilder
         awkward1 Array builder.
 
@@ -610,7 +615,7 @@ def _find_in_range(rec_stages, valid_stages, builder):
             if num_stages != 0:
                 found = 0
                 for j in i:
-                    if j in valid_stages:
+                    if min_stage <= j <= max_stage:
                         found += 1
                 if found == num_stages:
                     builder.append(1)
@@ -622,7 +627,7 @@ def _find_in_range(rec_stages, valid_stages, builder):
 
 
 @nb.jit(nopython=True)
-def _find_in_range_single(rec_stages, valid_stages, builder):
+def _find_in_range_single(rec_stages, min_stage, max_stage, builder):
     """Construct an awkward1 array with the same structure as tracks.rec_stages.
 
     When stages are within the range(min, max), the Array is filled with
@@ -632,19 +637,20 @@ def _find_in_range_single(rec_stages, valid_stages, builder):
     ----------
     rec_stages : awkward1.Array
         tracks.rec_stages of a SINGLE event.
-    valid_stages : set
-        set of valid stages.
+    min_stage: int
+        minimum value of rec_stages.
+    max_stage: int
+        minimum value of rec_stages.
     builder : awkward1.highlevel.ArrayBuilder
         awkward1 Array builder.
     """
-
     builder.begin_list()
     for s in rec_stages:
         num_stages = len(s)
         if num_stages != 0:
             found = 0
             for i in s:
-                if i in valid_stages:
+                if min_stage <= i <= max_stage:
                     found += 1
             if found == num_stages:
                 builder.append(1)
@@ -653,3 +659,103 @@ def _find_in_range_single(rec_stages, valid_stages, builder):
         else:
             builder.append(0)
     builder.end_list()
+
+
+def _mask_rec_stages_in_set(tracks, stages):
+    """Mask tracks where rec_stages are withing the range(min, max).
+
+    Parameters
+    ----------
+    tracks : km3io.offline.OfflineBranch
+        tracks, or one track, or slice of tracks, or slices of tracks.
+    stages : set
+        set of stages to look for in tracks.rec_stages.
+
+    Returns
+    -------
+    awkward1.Array
+        an awkward1 Array mask where True corresponds to the positions
+        where stages were found. False otherwise.
+    """
+    if isinstance(stages, set):
+
+        builder = ak1.ArrayBuilder()
+        if tracks.is_single:
+            _find_in_set_single(tracks.rec_stages, stages, builder)
+            return (builder.snapshot() == 1)[0]
+        else:
+            _find_in_set(tracks.rec_stages, stages, builder)
+            return builder.snapshot() == 1
+
+    else:
+        raise ValueError("stages must be a set")
+
+
+@nb.jit(nopython=True)
+def _find_in_set(rec_stages, stages, builder):
+    """Construct an awkward1 array with the same structure as tracks.rec_stages.
+
+    When all stages are found in rec_stages, the Array is filled with
+    value 1, otherwise it is filled with value 0.
+
+    Parameters
+    ----------
+    rec_stages : awkward1.Array
+        tracks.rec_stages of MULTILPLE events.
+    stages : set
+        set of stages.
+    builder : awkward1.highlevel.ArrayBuilder
+        awkward1 Array builder.
+
+    """
+    n = len(stages)
+    for s in rec_stages:
+        builder.begin_list()
+        for i in s:
+            num_stages = len(i)
+            if num_stages != 0:
+                found = 0
+                for j in i:
+                    if j in stages:
+                        found += 1
+                if found == n:
+                    builder.append(1)
+                else:
+                    builder.append(0)
+            else:
+                builder.append(0)
+        builder.end_list()
+
+
+@nb.jit(nopython=True)
+def _find_in_set_single(rec_stages, stages, builder):
+    """Construct an awkward1 array with the same structure as tracks.rec_stages.
+
+    When all stages  are found in rec_stages, the Array is filled with
+    value 1, otherwise it is filled with value 0.
+
+    Parameters
+    ----------
+    rec_stages : awkward1.Array
+        tracks.rec_stages of a SINGLE event.
+    stages : set
+        set of stages.
+    builder : awkward1.highlevel.ArrayBuilder
+        awkward1 Array builder.
+    """
+    n = len(stages)
+    builder.begin_list()
+    for s in rec_stages:
+        num_stages = len(s)
+        if num_stages != 0:
+            found = 0
+            for j in s:
+                if j in stages:
+                    found += 1
+            if found == n:
+                builder.append(1)
+            else:
+                builder.append(0)
+        else:
+            builder.append(0)
+    builder.end_list()
